#include "usereditordialog.h"
#include "ui_usereditordialog.h"
#include <QMessageBox>
#include <QSqlError>

UserEditorDialog::UserEditorDialog(QWidget *parent) :
    QDialog(parent),
    _ui(new Ui::UserEditorDialog)
{
    _ui->setupUi(this);

    setupModel();
    setupMapper();
    setupUi();
}

UserEditorDialog::~UserEditorDialog()
{
    delete _ui;
    delete _mapper;
    delete _model;
}

void UserEditorDialog::firstButton_Clicked()
{
    _mapper->toFirst(); // vezérlők beállítása
}

void UserEditorDialog::prevButton_Clicked()
{
    _mapper->toPrevious();
}

void UserEditorDialog::nextButton_Clicked()
{
    _mapper->toNext();
}

void UserEditorDialog::lastButton_Clicked()
{
    _mapper->toLast();
}


void UserEditorDialog::addButton_Clicked()
{
    int row = _mapper->currentIndex(); // lekérjük a sort
    _model->insertRow(row); // oda szúrunk be egy újat

    _mapper->setCurrentIndex(row);
}

void UserEditorDialog::removeButton_Clicked()
{
    if (_model->rowCount() > 0) // ellenőrizzüjk, hogy van-e mit törölni
    {
        int row = _mapper->currentIndex();
        _model->removeRow(row);
    }
    else
    {
        QMessageBox::warning(this, trUtf8("Nincs törölhető sor!"), trUtf8("A tábla már üres, nem lehet sort törölni!"));
    }
}

void UserEditorDialog::submitButton_Clicked()
{
    _model->database().transaction();

    if (_model->submitAll())
    {
        _model->database().commit();
        _model->select();
    }
    else
    {
        _model->database().rollback();
        QMessageBox::warning(this, trUtf8("Hiba történt a mentéskor!"), trUtf8("Az adatbázis a kvetkező hibát jelezte: %1").arg(_model->lastError().text()));
    }
}

void UserEditorDialog::setupModel()
{
    _model = new QSqlTableModel(this);
    _model->setTable("user");
    _model->setEditStrategy(QSqlTableModel::OnManualSubmit);
    _model->setHeaderData(0, Qt::Horizontal, trUtf8("Azonosító"));
    _model->setHeaderData(1, Qt::Horizontal, trUtf8("Jelszó"));
    _model->setHeaderData(2, Qt::Horizontal, trUtf8("Név"));
    _model->setHeaderData(3, Qt::Horizontal, trUtf8("Szint"));
    _model->select();
}

void UserEditorDialog::setupMapper()
{
    _mapper = new QDataWidgetMapper(this);
    _mapper->setModel(_model); // model beállítása
    _mapper->addMapping(_ui->userIdLineEdit, 0); // vezérlők adattársítása
    _mapper->addMapping(_ui->nameLineEdit, 2);
    _mapper->addMapping(_ui->passwordLineEdit, 1);
    _mapper->addMapping(_ui->levelSpinBox, 3);

    _mapper->toFirst(); // első sor beállítása
}

void UserEditorDialog::setupUi()
{
    connect(_ui->addButton, SIGNAL(clicked()), this, SLOT(addButton_Clicked()));
    connect(_ui->removeButton, SIGNAL(clicked()), this, SLOT(removeButton_Clicked()));
    connect(_ui->submitButton, SIGNAL(clicked()), this, SLOT(submitButton_Clicked()));
    connect(_ui->revertButton, SIGNAL(clicked()), _model, SLOT(revertAll()));

    connect(_ui->firstButton, SIGNAL(clicked()), this, SLOT(firstButton_Clicked()));
    connect(_ui->prevButton, SIGNAL(clicked()), this, SLOT(prevButton_Clicked()));
    connect(_ui->nextButton, SIGNAL(clicked()), this, SLOT(nextButton_Clicked()));
    connect(_ui->lastButton, SIGNAL(clicked()), this, SLOT(lastButton_Clicked()));

    setWindowTitle(trUtf8("Felhasználók szerkesztése"));
    setFixedSize(410, 192);
}
